Index: fetch_configs/webrtc_ios.py |
diff --git a/recipes/webrtc_ios.py b/fetch_configs/webrtc_ios.py |
similarity index 78% |
rename from recipes/webrtc_ios.py |
rename to fetch_configs/webrtc_ios.py |
index 550ad8d3fa9dd8b84c03feb808e65d3f5ebf14ae..f51fe22d0803ecedb5c51a49cf9943b92547730f 100644 |
--- a/recipes/webrtc_ios.py |
+++ b/fetch_configs/webrtc_ios.py |
@@ -4,19 +4,19 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class WebRTCIOS(recipe_util.Recipe): |
- """Basic Recipe alias for iOS -> WebRTC.""" |
+class WebRTCIOS(config_util.Config): |
+ """Basic Config alias for iOS -> WebRTC.""" |
@staticmethod |
def fetch_spec(props): |
return { |
'alias': { |
- 'recipe': 'webrtc', |
+ 'config': 'webrtc', |
'props': ['--target_os=ios,mac'], |
}, |
} |